.. This README is meant for consumption by humans and PyPI. PyPI can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on PyPI or github. It is a comment.

.. image:: https://github.com/collective/collective.contentrules.telegram/actions/workflows/plone-package.yml/badge.svg
    :target: https://github.com/collective/collective.contentrules.telegram/actions/workflows/plone-package.yml

.. image:: https://coveralls.io/repos/github/collective/collective.contentrules.telegram/badge.svg?branch=main
    :target: https://coveralls.io/github/collective/collective.contentrules.telegram?branch=main
    :alt: Coveralls

.. image:: https://codecov.io/gh/collective/collective.contentrules.telegram/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/collective/collective.contentrules.telegram

.. image:: https://img.shields.io/pypi/v/collective.contentrules.telegram.svg
    :target: https://pypi.python.org/pypi/collective.contentrules.telegram/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/status/collective.contentrules.telegram.svg
    :target: https://pypi.python.org/pypi/collective.contentrules.telegram
    :alt: Egg Status

.. image:: https://img.shields.io/pypi/pyversions/collective.contentrules.telegram.svg?style=plastic   :alt: Supported - Python Versions

.. image:: https://img.shields.io/pypi/l/collective.contentrules.telegram.svg
    :target: https://pypi.python.org/pypi/collective.contentrules.telegram/
    :alt: License


================================
collective.contentrules.telegram
================================

An add-on to enable sending messages to Telegram using content rules

Features
--------

- Content Rule action to send messages using Telegram



Installation
------------

Get a Telegram Bot Token. `Check the official documentation`_ to know how to do it.

Install collective.contentrules.telegram by adding it to your buildout::

    [buildout]

    ...

    eggs =
        collective.contentrules.telegram


and then running ``bin/buildout``


Authors
-------

Mikel Larreategi <mlarreategi@codesyntax.com>



Contribute
----------

- Issue Tracker: https://github.com/collective/collective.contentrules.telegram/issues
- Source Code: https://github.com/collective/collective.contentrules.telegram


Support
-------

If you are having issues, please let us know addin an issue in our GitHub repository.


License
-------

The project is licensed under the GPLv2.


.. _`Check the official documentation`: https://core.telegram.org/bots/api
